The transparent-proxy virtual IP range is hardcoded to use the 240.0.0.0/4 block and there is no configuration to change it. When service mesh / transparent proxy is enabled, virtual IPs are always assigned from that hardcoded CIDR, which can conflict with existing network ranges. Repro: enable Connect (for example, `connect { enabled = true }`) and observe assigned virtual IPs in 240.0.0.0/4. Expected: provide configuration options to set the IPv4 and IPv6 CIDR(s) used for virtual IP assignment so operators can choose nonconflicting ranges (e.g., `connect { enabled = true; virtual_ip_cidr_v4 = "240.10.0.0/16" }`).
